<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Signify
 */

get_header();

$enable_homepage_posts = signify_enable_homepage_posts();

if ( $enable_homepage_posts ) : ?>

	<div id="primary" class="content-area">
		<main id="main" class="site-main">
			<div class="archive-posts-wrapper ">
			<?php if ( have_posts() ) :
				$subtitle 			= get_theme_mod( 'signify_recent_posts_subtitle' );
				$signify_blog_title = get_theme_mod( 'signify_recent_posts_heading', esc_html__( 'From Our Blog', 'signify-pro' ) );
				$description  	    = get_theme_mod( 'signify_recent_posts_subheading', esc_html__( 'From The Blog', 'signify-pro' ) );

				if ( $signify_blog_title || $subtitle || $description ) : ?>
				<div class="section-heading-wrapper">
					<?php if ( $subtitle ) : ?>
						<div class="section-subtitle">
							<?php echo wp_kses_post( $subtitle ); ?>
						</div><!-- .section-description-wrapper -->
					<?php endif; ?>
					<?php if ( $signify_blog_title ) : ?>
						<div class="section-title-wrapper">
							<h2 class="section-title"><?php echo esc_html( $signify_blog_title ); ?></h2>
						</div><!-- .section-title-wrapper -->
					<?php endif; ?>

					<?php if ( $description ) : ?>
						<div class="section-description">
							<p><?php echo wp_kses_post( $description ); ?></p>
						</div><!-- .section-description-wrapper -->
					<?php endif; ?>

				</div><!-- .section-heading-wrap -->
				<?php endif; ?>

				<div class="section-content-wrapper <?php echo esc_attr( signify_get_posts_columns() ); ?>">
					<div id="infinite-post-wrap" class="archive-post-wrap grid">
						<?php
						/* Start the Loop */
						while ( have_posts() ) : the_post();

							/*
							 * Include the Post-Format-specific template for the content.
							 * If you want to override this in a child theme, then include a file
							 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
							 */
							get_template_part( 'template-parts/content/content', get_post_format() );

						endwhile;
						?>
					</div><!-- .archive-post-wrap -->
				</div><!-- .section-content-wrap -->

				<?php signify_content_nav(); ?>

				<?php
				else :

					get_template_part( 'template-parts/content/content', 'none' );

				endif; ?>
			</div><!-- .archive-post-wrapper -->
		</main><!-- #main -->
	</div><!-- #primary -->

<?php get_sidebar(); ?>
<?php endif; // $enable_homepage_posts
get_footer();
