<?php
/**
 * The template for displaying stats posts on the front page
 *
 * @package Solid_Construction
 */

$show_content  = get_theme_mod( 'signify_stats_show', 'excerpt' );
$signify_type = get_theme_mod( 'signify_stats_type', 'category' );
$number        = get_theme_mod( 'signify_stats_number', 4 );

$post_list  = array();
$no_of_post = 0;

$args = array(
	'post_type'           => 'post',
	'ignore_sticky_posts' => 1, // ignore sticky posts.
);

// Get valid number of posts.
if ( 'post' === $signify_type || 'page' === $signify_type ) {
	$args['post_type'] = $signify_type;

	for ( $i = 1; $i <= $number; $i++ ) {
		$signify_post_id = '';

		if ( 'post' === $signify_type ) {
			$signify_post_id = get_theme_mod( 'signify_stats_post_' . $i );
		} elseif ( 'page' === $signify_type ) {
			$signify_post_id = get_theme_mod( 'signify_stats_page_' . $i );
		} elseif ( $cpt_slug === $signify_type ) {
			$signify_post_id = get_theme_mod( 'signify_stats_cpt_' . $i );
		}

		if ( $signify_post_id && '' !== $signify_post_id ) {
			$post_list = array_merge( $post_list, array( $signify_post_id ) );

			$no_of_post++;
		}
	}

	$args['post__in'] = $post_list;
	$args['orderby']  = 'post__in';
} elseif ( 'category' === $signify_type ) {
	if ( $signify_cat = get_theme_mod( 'signify_stats_select_category' ) ) {
		$args['category__in'] = $signify_cat;
	}

	$no_of_post = $number;
}

if ( ! $no_of_post ) {
	return;
}

$args['posts_per_page'] = $no_of_post;

$loop = new WP_Query( $args );

while ( $loop->have_posts() ) :

	$loop->the_post();
	?>
	<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<div class="hentry-inner">
			<?php signify_post_thumbnail( 'thumbnail' ); ?>

			<div class="entry-container">
				<header class="entry-header">
					<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>
				</header>

				<?php
				if ( 'excerpt' === $show_content ) {
					?>
					<div class="entry-summary"><?php the_excerpt(); ?></div><!-- .entry-summary -->
					<?php
				} elseif ( 'full-content' === $show_content ) {
					$content = get_the_content();
					echo '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
				} ?>
			</div><!-- .entry-container -->
		</div> <!-- .hentry-inner -->
	</article> <!-- .article -->
<?php
endwhile;

wp_reset_postdata();
